searchNodes=[{"doc":"Provides functions to generate XML documents based on Ecto Schemas and maps. It uses XmlBuilder under the hood, see: https://github.com/joshnuss/xml_builder.","ref":"EctoXml.html","title":"EctoXml","type":"module"},{"doc":"Generates a partial XML element based on one ecto schema or map. The behaviour is idential to to_xml/3, except that it does not generate the XML document (e.g. &lt;?xml version=X encoding=Y?&gt;) with a root element name (e.g. &lt;root&gt; content &lt;/root&gt;), generating only the partial element instead. Example The following: %{ foo : &quot;bar&quot; } |&gt; EctoXml . to_partial_xml ( ) Results in: &lt;foo&gt;bar&lt;/foo&gt; Check to_xml/3 for more examples and use cases.","ref":"EctoXml.html#to_partial_xml/2","title":"EctoXml.to_partial_xml/2","type":"function"},{"doc":"Generates a XML document based on one ecto schema or map. The document_name argument refers to the XML root element name. Generating XML from maps The following: %{ foo : &quot;bar&quot; } |&gt; EctoXml . to_xml ( :root , format : :none ) Results in: &lt;?xml version=&quot;1.0&quot; encoding=&quot;UTF-8&quot;?&gt;&lt;root&gt;&lt;foo&gt;bar&lt;/foo&gt;&lt;/root&gt; Generating XML from an Ecto Schema For a given schema: defmodule Person do @moduledoc false use Ecto.Schema @primary_key false embedded_schema do field :name , :string end end The following: % Person { name : &quot;Foo Bar&quot; } |&gt; EctoXml . to_xml ( :person , format : :none ) Results in: &lt;?xml version=&quot;1.0&quot; encoding=&quot;UTF-8&quot;?&gt;&lt;person&gt;&lt;name&gt;Foo Bar&lt;/name&gt;&lt;/person&gt; Customizing field names For a given schema: defmodule Person do @moduledoc false use Ecto.Schema @primary_key false @derive { EctoXml.Builder , map_field_names : %{ :name =&gt; :custom_element_name } } embedded_schema do field :name , :string end end The following: % Person { name : &quot;Foo Bar&quot; } |&gt; EctoXml . to_xml ( :person , format : :none ) Results in: &lt;?xml version=&quot;1.0&quot; encoding=&quot;UTF-8&quot;?&gt;&lt;person&gt;&lt;custom_element_name&gt;Foo Bar&lt;/custom_element_name&gt;&lt;/person&gt;","ref":"EctoXml.html#to_xml/3","title":"EctoXml.to_xml/3","type":"function"},{"doc":"Build helper functions for EctoXml.","ref":"EctoXml.BuildHelper.html","title":"EctoXml.BuildHelper","type":"module"},{"doc":"Builds one XML element for a given field value.","ref":"EctoXml.BuildHelper.html#build_xml_element/3","title":"EctoXml.BuildHelper.build_xml_element/3","type":"function"},{"doc":"Builds a list of XML elements for a given ecto schema.","ref":"EctoXml.BuildHelper.html#build_xml_elements/2","title":"EctoXml.BuildHelper.build_xml_elements/2","type":"function"},{"doc":"Protocol that allows building ecto schemas into documents. Allows mapping the field names.","ref":"EctoXml.Builder.html","title":"EctoXml.Builder","type":"protocol"},{"doc":"","ref":"EctoXml.Builder.html#resolve_element_name/2","title":"EctoXml.Builder.resolve_element_name/2","type":"function"},{"doc":"","ref":"EctoXml.Builder.html#t:t/0","title":"EctoXml.Builder.t/0","type":"type"},{"doc":"Protocol to resolve XML element values.","ref":"EctoXml.ValueResolver.html","title":"EctoXml.ValueResolver","type":"protocol"},{"doc":"","ref":"EctoXml.ValueResolver.html#resolve/3","title":"EctoXml.ValueResolver.resolve/3","type":"function"},{"doc":"","ref":"EctoXml.ValueResolver.html#t:t/0","title":"EctoXml.ValueResolver.t/0","type":"type"},{"doc":"EctoXml","ref":"readme.html","title":"EctoXml","type":"extras"},{"doc":"EctoXml provides a way to easily generate XML documents from Ecto Schemas and maps. It supports converting all ecto schema properties to XML, such as embeds_one , has_one , embeds_many and has_many . On top of that, it also allows customizing name and value resolvers, giving you full control over your XML. Under the hood it uses Joshua Nussbaum amazing work on xml_builder , so the idea here is to remove complexity and DRY the process of generating XML based on maps and ecto schemas. Check the examples below to see some code and get started!","ref":"readme.html#overview","title":"EctoXml - Overview","type":"extras"},{"doc":"The package is available in Hex , and can be installed by adding ecto_xml to your list of dependencies in mix.exs : def deps do [ { :ecto_xml , &quot;~&gt; 1.0.0&quot; } ] end","ref":"readme.html#installation","title":"EctoXml - Installation","type":"extras"},{"doc":"Available functions EctoXml exports to_xml/3 and to_partial_xml/2 . The difference is that to_xml/3 allows us to build a full XML document with a root element whose name is passed as an atom. The to_partial_xml/2 function only generates the partial XML element, without the XML document and root element. The last argument for both functions is always the options argument - it is optional and is the same as xml_builder options . to_partial_xml/2 %{ name : &quot;Foo Bar&quot; } |&gt; EctoXml . to_partial_xml ( format : :none ) Produces: &lt;name&gt;Foo Bar&lt;/name&gt; to_xml/3 %{ name : &quot;Foo Bar&quot; } |&gt; EctoXml . to_xml ( :person , format : :none ) Produces: &lt;?xml version=&quot;1.0&quot; encoding=&quot;UTF-8&quot;?&gt;&lt;person&gt;&lt;name&gt;Foo Bar&lt;/name&gt;&lt;/person&gt; Using Maps The simplest form of usage is using maps. %{ name : &quot;Foo Bar&quot; } |&gt; EctoXml . to_xml ( :person ) Results in: &lt;?xml version=&quot;1.0&quot; encoding=&quot;UTF-8&quot;?&gt; &lt;person&gt; &lt;name&gt;Foo Bar&lt;/name&gt; &lt;/person&gt; Using Ecto Schemas We can also use any ecto schema (embedded or not) to generate our XML documents. defmodule Person do use Ecto.Schema @primary_key false embedded_schema do field :name , :string end end % Person { name : &quot;Foo Bar&quot; } |&gt; EctoXml . to_xml ( :person ) Results in: &lt;?xml version=&quot;1.0&quot; encoding=&quot;UTF-8&quot;?&gt; &lt;person&gt; &lt;name&gt;Foo Bar&lt;/name&gt; &lt;/person&gt; Customizing element names We can change any element name for the ecto schema being serialized by deriving from the EctoXml.Builder protocol. Here, we have two optional properties: map_field_names : changes the element name for any field map_array_names : changes the element name for array fields Note that in the case of arrays, the map_field_names option will not be applied to the array itself. Instead, it will be applied to the array items, allowing you to customize each item name. In order to change the array element name, we must use map_array_names . defmodule Post do use Ecto.Schema @primary_key false @derive { EctoXml.Builder , map_field_names : %{ :title =&gt; :custom_title , :comments =&gt; :a_comment } , map_array_names : %{ :comments =&gt; :custom_comments } } embedded_schema do field :title , :string embeds_many :comments , Comment end end defmodule Comment do use Ecto.Schema @primary_key false embedded_schema do field :content , :string end end % Post { title : &quot;Foo Bar&quot; , comments : [ % Comment { content : &quot;Comment 1&quot; } , % Comment { content : &quot;Comment 2&quot; } , ] } |&gt; EctoXml . to_xml ( :post ) Results in: &lt;?xml version=&quot;1.0&quot; encoding=&quot;UTF-8&quot;?&gt; &lt;post&gt; &lt;custom_comments&gt; &lt;a_comment&gt; &lt;content&gt;Comment 1&lt;/content&gt; &lt;/a_comment&gt; &lt;a_comment&gt; &lt;content&gt;Comment 2&lt;/content&gt; &lt;/a_comment&gt; &lt;/custom_comments&gt; &lt;custom_title&gt;Foo Bar&lt;/custom_title&gt; &lt;/post&gt; Customizing element values We can use the EctoXml.ValueResolver protocol to customize and resolve the value for any element type. It receives some options to resolve the value: value : the original element value key : the field name base_module : the base module which is being serialized to XML Here's one example for a tuple: defimpl EctoXml.ValueResolver , for : Tuple do @moduledoc &quot;ValueResolver implementation for Tuple that for some mysterious reason, always returns 42.&quot; def resolve ( _value , _key , _base_module ) do &quot;42&quot; end end %{ value : { :ok , &quot;foo bar&quot; } } |&gt; EctoXml . to_xml ( :tuple ) Produces: &lt;?xml version=&quot;1.0&quot; encoding=&quot;UTF-8&quot;?&gt; &lt;tuple&gt; &lt;value&gt;42&lt;/value&gt; &lt;/tuple&gt;","ref":"readme.html#examples","title":"EctoXml - Examples","type":"extras"},{"doc":"This source code is licensed under the MIT License . Copyright (c) 2021-present, Pedro Bini. All rights reserved.","ref":"readme.html#license","title":"EctoXml - License","type":"extras"}]